# Pachyderm MkDocs theme 

A Material Design theme for Pachyderm Documentation built on [MkDocs][1].


## Quick start

Install the latest version of Material with `pip`:

``` sh
pip install mkdocs-pachyderm
```

Append the following line to your project's `mkdocs.yml`:

``` yaml
theme:
  name: pachydermdocs
```
